/* This is "block7.c", written to accompany Introduction to
   Scientific Programming by Joseph L. Zachary .*/

/* This program calculates the position of a block on a finite ramp in
   the presence of friction as described in Chapter 12 of the text.
   It uses a programmer-function to help in this task, and illustrates
   the use of function prototypes. */


#include <stdio.h>
#include <math.h>



/* This is the prototype for the "position" function, which is
   implemented at the end of this program.  By including this
   prototype, it is possible for the implementation of "main" to
   appear before the implementation of "position". */

double position (double theta, double mu,
                 double limit, double time);



/* We obtain the angle of the ramp in degrees, the coefficient of
   friction of the block against the ramp, the length of the ramp, and
   the elapsed time in seconds since the block was released, and
   display the distance in meters of the block from its original
   position. */

void main (void)
{
  double angle,    /* Angle of inclination of the ramp in degrees. */
         theta,    /* Angle of inclination of the ramp in radians. */
         time,     /* Time since block was released in seconds. */
         pos,      /* Position of block in meters. */
         mu,       /* Coefficient of friction of block against ramp. */
         limit;    /* Length of the ramp in meters. */


  /* Obtain the ramp angle and convert to radians. */

  printf("Enter the angle of the ramp (degrees): ");
  scanf("%lf", &angle);
  theta = acos(-1) * angle/180;


  /* Obtain the coefficient of friction. */

  printf("Enter the coefficient of friction: ");
  scanf("%lf", &mu);


  /* Obtain the length of the ramp. */

  printf("Enter the length of the ramp (meters): ");
  scanf("%lf", &limit);


  /* Obtain the time since release. */

  printf("Enter the time (seconds): ");
  scanf("%lf", &time);


  /* Calculate the position of the block by using the
  programmer-defined function "position". */

  pos = position(theta, mu, limit, time);


  /* Display the result. */

  printf("Position of the block is %g meters\n", pos);

}



/* This function reports the position in meters of a block "time"
   seconds after it is released on a ramp of length "limit" meters
   that is inclined at "theta" radians.  The the coefficient of
   friction of the block against the ramp is "mu". */

double position (double theta, double mu,
                 double limit, double time)
{

  double pos,      /* Position of block in meters. */
         factor;   /* Dimensionless factor that determines how the
                      block accelerates. */


  /* Calculate the factor that governs acceleration. */

  factor = sin(theta) - mu * cos(theta);


  /* Calculate the position of the block as if the ramp were infinite.
     Prior to time zero, the block does not move.  If "factor" is not
     positive, the block does not move either. */

  if (time < 0 || factor < 0) {
    pos = 0;
  }
  else {
    pos = 1./2. * 9.8 * factor * time * time;
  }


  /* If the position of the block on an infinite ramp would be beyond
     the end of the finite ramp we are really dealing with, set the
     position back to the length of the finite ramp. */

  if (pos > limit) {
    pos = limit;
  }


  /* Return the result. */
  
  return(pos);

}
