(*^

::[	frontEndVersion = "Microsoft Windows Mathematica Notebook Front End Version 2.2";
	microsoftWindowsStandardFontEncoding;
	fontset = title, "Times New Roman", 24, L0, center, nohscroll, bold;
	fontset = subtitle, "Times New Roman", 18, L0, center, nohscroll, bold;
	fontset = subsubtitle, "Times New Roman", 14, L0, center, nohscroll, bold;
	fontset = section, "Times New Roman", 14, L0, bold, grayBox;
	fontset = subsection, "Times New Roman", 12, L0, bold, blackBox;
	fontset = subsubsection, "Times New Roman", 10, L0, bold, whiteBox;
	fontset = text, "Times New Roman", 12, L0;
	fontset = smalltext, "Times New Roman", 10, L0;
	fontset = input, "Courier New", 12, L0, nowordwrap, bold;
	fontset = output, "Courier New", 12, L0, nowordwrap;
	fontset = message, "Courier New", 10, L0, nowordwrap, R65535;
	fontset = print, "Courier New", 10, L0, nowordwrap;
	fontset = info, "Courier New", 10, L0, nowordwrap;
	fontset = postscript, "Courier New", 8, L0, nowordwrap;
	fontset = name, "Times New Roman", 10, L0, nohscroll, italic, B65535;
	fontset = header, "Times New Roman", 10, L0, right, nohscroll;
	fontset = footer, "Times New Roman", 10, L0, right, nohscroll;
	fontset = help, "Times New Roman", 10, L0, nohscroll;
	fontset = clipboard, "Times New Roman", 12, L0, nohscroll;
	fontset = completions, "Times New Roman", 12, L0, nowordwrap, nohscroll;
	fontset = graphics, "Courier New", 10, L0, nowordwrap, nohscroll;
	fontset = special1, "Times New Roman", 12, L0, nowordwrap, nohscroll;
	fontset = special2, "Times New Roman", 12, L0, center, nowordwrap, nohscroll;
	fontset = special3, "Times New Roman", 12, L0, right, nowordwrap, nohscroll;
	fontset = special4, "Times New Roman", 12, L0, nowordwrap, nohscroll;
	fontset = special5, "Times New Roman", 12, L0, nowordwrap, nohscroll;
	fontset = leftheader, "Times New Roman", 12, L0, nowordwrap, nohscroll;
	fontset = leftfooter, "Times New Roman", 12, L0, nowordwrap, nohscroll;
	fontset = reserved1, "Courier New", 10, L0, nowordwrap, nohscroll;]
:[font = subsection; inactive; backColorRed = 65535; backColorGreen = 65535; backColorBlue = 65535; fontColorRed = 0; fontColorGreen = 0; fontColorBlue = 0; bold; fontName = "Times New Roman"; fontSize = 12; ]
This notebook contains the Mathematica commands from Appendix D of 
Introduction to Scientific Programming by Joseph L. Zachary.
:[font = text; inactive; ]

(D.1)  This compact syntax for writing floating-point numbers in scientific notation does not work in Mathematica 2.2
:[font = input; nowordwrap; ]
57.8*^6 / 5.713*^9
:[font = text; inactive; ]

(D.2)  Consequently, you must include the exponent base 10 that you are allowed to omit in Mathematica 3.3.
:[font = input; nowordwrap; ]
5.78*10^6 / 5.713*10^9
:[font = text; inactive; ]

(D.3)  But keep in mind that the precedence rules apply; (D.2) yielded the wrong answer because the 10^9 was treated as if it were in the numerator.  Use parentheses to correct the problem.
:[font = input; nowordwrap; ]
5.78*10^6 / (5.713*10^9)
:[font = text; inactive; ]

(D.4)  Typeset mathematics input is not supported by Mathematica 2.2.
:[font = text; inactive; ]

(D.5)  Instead, everything has to be spelled out explicitly.
:[font = input; nowordwrap; ]
Integrate[1/(2*Sqrt[x]), x]
:[font = text; inactive; ]

(D.6)  When mixed with rational numbers, symbols such as Pi are not converted into their numerical equivalent.
:[font = input; nowordwrap; ]
2 * Pi
:[font = text; inactive; ]

(D.7)  In Mathematica 2.2, this holds true even when floating-point numbers are involved.
:[font = input; nowordwrap; ]
2.0 * Pi
:[font = text; inactive; ]

The cure is to use "N" to explicitly convert expressions to floating-point form.
:[font = input; nowordwrap; ]
N[2.0 * Pi]
:[font = text; inactive; ]

(D.9)  Here is another example of the same thing, this time with the constant "EulerGamma".
:[font = input; nowordwrap; ]
0.5 * (PolyGamma[1.*10^9 + 1] + EulerGamma)
:[font = text; inactive; ]

(D.10)  Again, the cure is to use "N".
:[font = input; nowordwrap; ]
N[0.5 * (PolyGamma[1.*10^9 + 1] + EulerGamma)]
:[font = text; inactive; ]

(D.11)  Here is a function that uses the constant "Pi".
:[font = input; nowordwrap; ]
cow[theta_] := Sin[theta] - theta*Cos[theta] - Pi/2
:[font = text; inactive; ]

(D.12)  As a result, this call to the function produces a result involving "Pi".
:[font = input; nowordwrap; ]
cow[2.5]
:[font = text; inactive; ]

(D.13)  This behavior can cause problems in the context of relational operators.  In Mathematica 2.2, this expression does not simplify to True as you might expect.
:[font = input; nowordwrap; ]
Pi >= 3
:[font = text; inactive; ]

(D.14)  As a result, this "If" expression produces no value.
:[font = input; nowordwrap; ]
If[Pi >= 3, 1, 2]
:[font = text; inactive; ]

The solution, as always, is to use "N".
:[font = input; nowordwrap; ]

If[N[Pi] >= 3, 1, 2]
:[font = text; inactive; ]

(D.15)  Mathematica 2.2 cannot simplify this sum.
:[font = input; nowordwrap; ]
Sum[1/2^n, {n,1,Infinity}]
:[font = text; inactive; ]

Here are some definitions derived from Chapter 8.
:[font = input; nowordwrap; ]

pow = 18432. * t
maxPower = 5.0*10^6
:[font = text; inactive; ]

(D.16) Mathematica 2.2 cannot solve this equation because it involves "Abs".
:[font = input; nowordwrap; ]
threshold = Solve[Abs[pow] == maxPower, t]
:[font = text; inactive; ]

(D.17)  We can deal with this by splitting the equation into two equations, and solving them individually.  Here we find the positive solution ...
:[font = input; nowordwrap; ]
Solve[pow == maxPower, t]
:[font = text; inactive; ]

(D.18)  ... and here we find the negative solution.
:[font = input; nowordwrap; ]
Solve[-pow == maxPower, t]
:[font = text; inactive; ]

(D.19)  Mathematica 2.2 is unable to solve this equation.
:[font = input; nowordwrap; ]
Solve[Cos[alpha] == Sin[alpha], alpha]
^*)