(*^

::[	frontEndVersion = "Microsoft Windows Mathematica Notebook Front End Version 2.2";
	microsoftWindowsStandardFontEncoding;
	fontset = title, "Times New Roman", 24, L0, center, nohscroll, bold;
	fontset = subtitle, "Times New Roman", 18, L0, center, nohscroll, bold;
	fontset = subsubtitle, "Times New Roman", 14, L0, center, nohscroll, bold;
	fontset = section, "Times New Roman", 14, L0, bold, grayBox;
	fontset = subsection, "Times New Roman", 12, L0, bold, blackBox;
	fontset = subsubsection, "Times New Roman", 10, L0, bold, whiteBox;
	fontset = text, "Times New Roman", 12, L0;
	fontset = smalltext, "Times New Roman", 10, L0;
	fontset = input, "Courier New", 12, L0, nowordwrap, bold;
	fontset = output, "Courier New", 12, L0, nowordwrap;
	fontset = message, "Courier New", 10, L0, nowordwrap, R65535;
	fontset = print, "Courier New", 10, L0, nowordwrap;
	fontset = info, "Courier New", 10, L0, nowordwrap;
	fontset = postscript, "Courier New", 8, L0, nowordwrap;
	fontset = name, "Times New Roman", 10, L0, nohscroll, italic, B65535;
	fontset = header, "Times New Roman", 10, L0, right, nohscroll;
	fontset = footer, "Times New Roman", 10, L0, right, nohscroll;
	fontset = help, "Times New Roman", 10, L0, nohscroll;
	fontset = clipboard, "Times New Roman", 12, L0, nohscroll;
	fontset = completions, "Times New Roman", 12, L0, nowordwrap, nohscroll;
	fontset = graphics, "Courier New", 10, L0, nowordwrap, nohscroll;
	fontset = special1, "Times New Roman", 12, L0, nowordwrap, nohscroll;
	fontset = special2, "Times New Roman", 12, L0, center, nowordwrap, nohscroll;
	fontset = special3, "Times New Roman", 12, L0, right, nowordwrap, nohscroll;
	fontset = special4, "Times New Roman", 12, L0, nowordwrap, nohscroll;
	fontset = special5, "Times New Roman", 12, L0, nowordwrap, nohscroll;
	fontset = leftheader, "Times New Roman", 12, L0, nowordwrap, nohscroll;
	fontset = leftfooter, "Times New Roman", 12, L0, nowordwrap, nohscroll;
	fontset = reserved1, "Courier New", 10, L0, nowordwrap, nohscroll;]
:[font = subsection; inactive; ]
This notebook contains the Mathematica commands from Chapter 7 of Introduction
 to Scientific Programming by Joseph L. Zachary.
:[font = text; inactive; ]

(7.7)  We use "Solve" to find the two times at which a projectile is at ground
 level.
:[font = input; nowordwrap; ]
Solve[v*t*Sin[theta] - (1/2)*g*t^2 == 0, t]
:[font = text; inactive; ]

(7.9)  We create a function "horizontal" that returns the horizonal position 
in meters of a projectile "t" seconds after it is fired with initial speed "v"
 m/sec and initial angle "theta" radians.  This function ignores what happens 
when the projectile hits the ground.
:[font = input; nowordwrap; ]
horizontal[v_, theta_, t_] := v * t * Cos[theta]
:[font = text; inactive; ]

(7.10)  We create a function "vertical" that returns the vertical position in 
meters of a projectile "t" seconds after it is fired with initial speed "v" m/
sec and initial angle "theta" radians.  This function ignores what happens 
when the projectile hits the ground. 
:[font = input; nowordwrap; ]
vertical[v_, theta_, t_] := v * t * Sin[theta] -
                             1/2 * g * t^2
:[font = text; inactive; ]

(7.11)  We create a function "duration" that reports the time in seconds that 
elapses before a projectile fired with initial speed "v" m/sec and an initial 
angle "theta" radians hits the ground.
:[font = input; nowordwrap; ]
duration[v_, theta_] := 2 * v * Sin[theta] / g
:[font = text; inactive; ]

(7.12)  The horizontal position of a projectile fired straight up will always 
be zero.
:[font = input; nowordwrap; ]
horizontal[100, Pi/2, 10]
:[font = text; inactive; ]

(7.13)  We calculate the horizontal position after 10 seconds of a projectile 
fired at 45 degrees with a speed of 100 m/sec.
:[font = input; nowordwrap; ]
horizontal[100, Pi/4, 10]
:[font = text; inactive; ]

(7.14)  Trigonometric functions such as "Cos" give exact answers if their 
parameters are exact multiples of pi.
:[font = input; nowordwrap; ]
Cos[Pi/4]
:[font = text; inactive; ]

(7.15)  Even though this result is not completely reduced, it is still exact.
:[font = input; nowordwrap; ]
horizontal[100, Pi/8, 10]
:[font = text; inactive; ]

(7.16)  We use "N" to convert the result from (7.13) into floating-point form.
:[font = input; nowordwrap; ]
N[horizontal[100, Pi/4, 10]]
:[font = text; inactive; ]

(7.17)  The symbolic constant "g" appears in this result because "g" is used 
in the implementation of "vertical" but is nowhere given a value.
:[font = input; nowordwrap; ]
N[vertical[100, Pi/4, 10]]
:[font = text; inactive; ]

(7.18)  The symbolic constant "g" appears in this result for the same reason 
that it appeared in the result of (7.17).
:[font = input; nowordwrap; ]
vertical[100, Pi/4, 10]
:[font = text; inactive; ]

(7.19)  This illustrates in a bit more detail what happens when the call to "
vertical" from (7.18) is made.  Mathematica substitutes 100 for "v", Pi/4 for 
"theta", and 10 for "t" in the body of "vertical", which results in the 
following expression.  Mathematica then evaluates the expression as if it had 
been typed in. 
:[font = input; nowordwrap; ]
100 * 10 * Sin[Pi/4] - 1/2 * g * 10^2
:[font = text; inactive; ]

(7.20)  We assign "g" a value of 9.8 m/sec/sec.
:[font = input; nowordwrap; ]
g = 9.8
:[font = text; inactive; ]

(7.21)  Now when we repeat (7.17) we get a numerical answer.
:[font = input; nowordwrap; ]
N[vertical[100, Pi/4, 10]]
:[font = text; inactive; ]

(7.22)  This calculates the duration of the flight of a projectile fired at 
100 m/sec at an angle of 45 degrees.
:[font = input; nowordwrap; ]
N[duration[100, Pi/4]]
:[font = text; inactive; ]

(7.23)  We might have chosen to define "vertical" so that acceleration due to 
gravity was coded directly in, instead of using the free variable "g" as we 
did in (7.10).
:[font = input; nowordwrap; ]
vertical[v_, theta_, t_] := v * t * Sin[theta] -
                              1/2 * 9.8 * t^2
:[font = text; inactive; ]

(7.24)  We might also have chosen to define "vertical" so that acceleration 
due to gravity was a fourth parameter.
:[font = input; nowordwrap; ]
vertical[v_, theta_, t_, g_] := v * t * Sin[theta] -
                                 1/2 * g * t^2
:[font = text; inactive; ]

(7.25)  We could then have specified gravitational constants other than 9.8 as
 a fourth parameter.
:[font = input; nowordwrap; ]
N[vertical[100, Pi/4, 10, 4.9]]
:[font = text; inactive; ]

(7.26)  We could also have given "g" a default value.
:[font = input; nowordwrap; ]
vertical[v_, theta_, t_, g_:9.8] := v * t * Sin[theta] -
                                      1/2 * g * t^2
:[font = text; inactive; ]

Let's revert to the original definition of "vertical" from (7.10).
:[font = input; nowordwrap; ]
vertical[v_, theta_, t_] := v * t * Sin[theta] -
                             1/2 * g * t^2
:[font = text; inactive; ]

(7.27)  Because "t" is symbolic, the result here is given in terms of "t".
:[font = input; nowordwrap; ]
vertical[100, Pi/4, t]
:[font = text; inactive; ]

(7.28)  The first parameter to this form of "Plot" must be a symbolic 
expression in the independent variable.  This variable is identified, and its 
range specified, by the second parameter.
:[font = input; nowordwrap; ]
Plot[vertical[100, Pi/4, t], {t, 0, 20}]
:[font = text; inactive; ]

(7.29)  The plot from (7.26) shows the height of the projectile as if it 
continues falling even after it hits the ground.  Here we specify bounds on "t
" that correspond only to the duration of the projectile's flight.
:[font = input; nowordwrap; ]
Plot[vertical[100, Pi/4, t],
     {t, 0, 20},
     PlotRange->{0, 260}]
:[font = text; inactive; ]

(7.30)  In (7.29), we "guessed at" the appropriate bounds to put on the 
vertical axis.  Here, we specify the bounds on the horizonal axis exactly, 
which means that the vertical axis is automatically scaled properly.
:[font = input; nowordwrap; ]
Plot[vertical[100, Pi/4, t],
     {t, 0, duration[100, Pi/4]}]
:[font = text; inactive; ]

(7.31)  We repeat (7.30), but use the "AxesLabel" option to label the axes.
:[font = input; nowordwrap; ]
Plot[vertical[100, Pi/4, t],
     {t, 0, duration[100, Pi/4]},
     AxesLabel->{"sec", "m"}]
:[font = text; inactive; ]

(7.32)  This is an example of a list.
:[font = input; nowordwrap; ]
{2+2, 2-2, 2*2, 2/2}
:[font = text; inactive; ]

(7.33)  The "Table" function is useful for building lists.  Here, we construct
 a list of the squares of the odd numbers between 1 and 21.
:[font = input; nowordwrap; ]
Table[n^2, {n, 1, 21, 2}]
:[font = text; inactive; ]

(7.34)    We include three different curves in a single plot by specifying a 
list of three different dependent expressions as the first parameter to "Plot".
Unfortunately, two of the height curves extend below the ground. 
:[font = input; nowordwrap; ]
Plot[{vertical[100, Pi/6, t],
      vertical[100, Pi/4, t],
      vertical[100, Pi/3, t]},
     {t, 0, duration[100, Pi/3]},
     AxesLabel->{"sec", "m"}]
:[font = text; inactive; ]

(7.35)  Here's an alternative way to create the plot from (7.34).  We create 
each of the three curves individually and save them to variables.  First, the 
Pi/6 trajectory ...
:[font = input; nowordwrap; ]
plot30 = Plot[vertical[100, Pi/6, t],
              {t, 0, duration[100, Pi/6]}]
:[font = text; inactive; ]

(7.36)  ... next, the Pi/4 trajectory ...
:[font = input; nowordwrap; ]
plot45 = Plot[vertical[100, Pi/4, t],
              {t, 0, duration[100, Pi/4]}]
:[font = text; inactive; ]

(7.37)  ... and last, the Pi/3 trajectory ...
:[font = input; nowordwrap; ]
plot60 = Plot[vertical[100, Pi/3, t],
              {t, 0, duration[100, Pi/3]}]
:[font = text; inactive; ]

(7.38)  ... Finally, we use "Show" to compute the trajectories on one plot.
:[font = input; nowordwrap; ]
Show[{plot30, plot45, plot60},
     AxesLabel->{"sec", "m"}]
:[font = text; inactive; ]

(7.39)  On the same plot, we show the horizontal and vertical positions of a 
projectile fired at 100 m/sec at an angle of 45 degrees.
:[font = input; nowordwrap; ]
Plot[{horizontal[100, Pi/4, t],
      vertical[100, Pi/4, t]},
     {t, 0, duration[100, Pi/4]},
     AxesLabel->{"sec", "m"}]
:[font = text; inactive; ]

(7.40)  We create a parametric plot using the dependent expressions from
(7.39).  We do this by using "ParametricPlot" and listing the two dependent 
expressions.  The horizontal position is plotted against the horizonal axis, 
and the vertical position is plotted against the vertical axis.  Time does not
 appear explicitly in the plot.
:[font = input; nowordwrap; ]
ParametricPlot[{horizontal[100, Pi/4, t],
                vertical[100, Pi/4, t]},
               {t, 0, duration[100, Pi/4]},
               AxesLabel->{"m", "m"}]
:[font = text; inactive; ]

(7.41)  We put three parametric curves on the same plot.  We create the Pi/6 
curve ...
:[font = input; nowordwrap; ]
pplot30 =
  ParametricPlot[{horizontal[100, Pi/6, t],
                  vertical[100, Pi/6, t]},
                 {t, 0, duration[100, Pi/6]}]
:[font = text; inactive; ]

(7.42)  ... the Pi/4 curve ...
:[font = input; nowordwrap; ]
pplot45 =
  ParametricPlot[{horizontal[100, Pi/4, t],
                  vertical[100, Pi/4, t]},
                 {t, 0, duration[100, Pi/4]}]
:[font = text; inactive; ]

(7.43)  ... and the Pi/3 curve.
:[font = input; nowordwrap; ]
pplot60 =
  ParametricPlot[{horizontal[100, Pi/3, t],
                  vertical[100, Pi/3, t]},
                 {t, 0, duration[100, Pi/3]}]
:[font = text; inactive; ]

(7.44)  Finally we use "Show" to combine the three curves.  We use the
"AspectRatio" optional parameter to ensure that the scales of the two axes are 
identical.
:[font = input; nowordwrap; backColorRed = 65535; backColorGreen = 65535; backColorBlue = 65535; fontColorRed = 0; fontColorGreen = 0; fontColorBlue = 0; bold; fontName = "Courier New"; fontSize = 12; ]
Show[{pplot30, pplot45, pplot60},
     AxesLabel->{"m", "m"},
     AspectRatio->Automatic]
:[font = text; inactive; ]

(7.45)  We create a sequence of plots showing how the height of a projectile 
depends on both time and the initial angle of its trajectory.  Each plot shows
 the height of the projectile against time for a particular initial angle.  
The initial angle varies from 0 degrees in the first plot to 90 degrees in the
 last plot.

To animate the 13 plots, select all of the plots and choose "Animate
Selected Graphics" from the "Graph" menu.  You can control the animation
with the icons that will appear at the bottom of the notebook.
:[font = input; nowordwrap; ]
Table[Plot[vertical[100, angle, t],
           {t, 0, duration[100, Pi/2]},
           PlotRange->{0, 550},
           AxesLabel->{"m", "m"}],
      {angle, 0, Pi/2, Pi/24}]
:[font = text; inactive; ]

(7.46)  We create an animation showing how the trajectory of a projectile 
depends on both time and the the initial angle of its trajectory.  In each 
frame of the animation, a parametric plot of the projectile's position is 
shown.  During the animation, the initial angle varies from 0 to 90 degrees.
:[font = input; nowordwrap; ]
Table[ParametricPlot[{horizontal[100, angle, t],
                      vertical[100, angle, t]},
                     {t, 0, duration[100, Pi/2]},
                     PlotRange->{{0,1100},{0,550}},
                     AxesLabel->{"m", "m"}],
      {angle, 0, Pi/2, Pi/24}]

^*)