(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      4632,        165]*)
(*NotebookOutlinePosition[      5269,        188]*)
(*  CellTagsIndexPosition[      5225,        184]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["This notebook contains the ", "Text"],
  StyleBox["Mathematica", "Text",
    FontSlant->"Italic"],
  StyleBox[" commands from Chapter 4 of ", "Text"],
  StyleBox["Introduction to Scientific Programming", "Text",
    FontSlant->"Italic"],
  StyleBox[" by Joseph L. Zachary.", "Text"]
}], "Subsection"],

Cell["\<\
(4.2)  We use rational arithmetic to add up the reciprocals of the \
first ten even numbers.  The answer is exact.\
\>", "Text"],

Cell["\<\
rat10 = 1/2 + 1/4 + 1/6 + 1/8 + 1/10 + 1/12 + 1/14 + 1/16 + 1/18 + \
1/20\
\>", "Input"],

Cell["\<\
(4.3)  This is a six-digit floating-point approximations to the \
rational sum from (4.2).\
\>", "Text"],

Cell["N[rat10]", "Input"],

Cell["\<\
(4.4)  We use floating-point arithmetic to add up the reciprocals \
of the first ten even numbers.  We get the same answer as in (4.3).\
\>", 
  "Text"],

Cell["\<\
float10 = 1/2. + 1/4. + 1/6. + 1/8. + 1/10. + 1/12. + 1/14. + 1/16. \
+ 1/18. + 1/20.\
\>", "Input"],

Cell[TextData[{
  "(4.5)  We load the \"Blocks\" package from the custom ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " library \"ISP\" that accompanies the book."
}], "Text"],

Cell["Needs[\"ISP`Blocks`\"]", "Input"],

Cell["\<\
(4.6)  We display the names of the functions contained in the \
\"Blocks\" package.\
\>", "Text"],

Cell["Names[\"ISP`Blocks`*\"]", "Input"],

Cell["(4.7)  We calculate the sum from (4.2) using \"BlockRat\".", "Text"],

Cell["BlockRat[10]", "Input"],

Cell["(4.8)  We calculate the sum from (4.3) using \"BlockFloat\".", "Text"],

Cell["BlockFloat[10]", "Input"],

Cell["\<\
(4.9)  We calculate the same sum as in 4.8, but using simulated \
two-digit floating-point numbers.  Notice that quite a bit of roundoff error \
accumulates.\
\>", "Text"],

Cell["BlockPrecision[10, 2]", "Input"],

Cell["\<\
(4.10)  This calculates the amount of computer time it takes to \
calculate \"BlockFloat[5000]\" on your computer.\
\>", "Text"],

Cell["Timing[BlockFloat[5000]]", "Input"],

Cell["\<\
(4.11)  Here we see that, using two-digit floating-point \
arithmetic, the ten-term sum ...\
\>", "Text"],

Cell["BlockPrecision[10, 2]", "Input"],

Cell["(4.12) ... and the twenty-term sum produce the same answer.", "Text"],

Cell["BlockPrecision[20, 2]", "Input"],

Cell["\<\
(4.13)  If we sum the terms beginning with the smallest, however, \
the ten-term sum ...\
\>", "Text"],

Cell["BlockPrecision[-10, 2]", "Input"],

Cell["\<\
(4.14) ... and the twenty-term sum produce different answers.\
\>", 
  "Text"],

Cell["BlockPrecision[-20, 2]", "Input"],

Cell["\<\
(4.18)  We can exploit a much better method for computing the sum \
of the first billion even terms of the harmonic series.\
\>", "Text"],

Cell["0.5 * (PolyGamma[1.*^9 + 1] + EulerGamma)", "Input"],

Cell["(4.19)  The ! operator computes the factorial function.", "Text"],

Cell["5!", "Input"]
}, Open  ]]
},
FrontEndVersion->"X 3.0",
ScreenRectangle->{{0, 1280}, {0, 1024}},
WindowSize->{520, 600},
WindowMargins->{{150, Automatic}, {Automatic, 52}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 328, 8, 66, "Subsection"],
Cell[2062, 61, 138, 3, 50, "Text"],
Cell[2203, 66, 98, 3, 42, "Input"],
Cell[2304, 71, 114, 3, 32, "Text"],
Cell[2421, 76, 25, 0, 27, "Input"],
Cell[2449, 78, 162, 4, 50, "Text"],
Cell[2614, 84, 110, 3, 42, "Input"],
Cell[2727, 89, 187, 5, 50, "Text"],
Cell[2917, 96, 39, 0, 27, "Input"],
Cell[2959, 98, 107, 3, 32, "Text"],
Cell[3069, 103, 40, 0, 27, "Input"],
Cell[3112, 105, 74, 0, 32, "Text"],
Cell[3189, 107, 29, 0, 27, "Input"],
Cell[3221, 109, 76, 0, 32, "Text"],
Cell[3300, 111, 31, 0, 27, "Input"],
Cell[3334, 113, 181, 4, 50, "Text"],
Cell[3518, 119, 38, 0, 27, "Input"],
Cell[3559, 121, 138, 3, 50, "Text"],
Cell[3700, 126, 41, 0, 27, "Input"],
Cell[3744, 128, 115, 3, 32, "Text"],
Cell[3862, 133, 38, 0, 27, "Input"],
Cell[3903, 135, 75, 0, 32, "Text"],
Cell[3981, 137, 38, 0, 27, "Input"],
Cell[4022, 139, 112, 3, 32, "Text"],
Cell[4137, 144, 39, 0, 27, "Input"],
Cell[4179, 146, 88, 3, 32, "Text"],
Cell[4270, 151, 39, 0, 27, "Input"],
Cell[4312, 153, 147, 3, 50, "Text"],
Cell[4462, 158, 58, 0, 27, "Input"],
Cell[4523, 160, 71, 0, 32, "Text"],
Cell[4597, 162, 19, 0, 27, "Input"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

