(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     11025,        383]*)
(*NotebookOutlinePosition[     11680,        407]*)
(*  CellTagsIndexPosition[     11636,        403]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  "This notebook contains the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " commands from Chapter 6 of ",
  StyleBox["Introduction to Scientific Programming",
    FontSlant->"Italic"],
  " by Joseph L. Zachary."
}], "Subsection"],

Cell["\<\
(6.1)  Let's calculate the effect of 6% simple interest over a \
period of three years.  In the beginning we have a balance of $1000.\
\>", 
  "Text"],

Cell["year0 = 1000.", "Input"],

Cell["\<\
(6.2)  After a year passes we have 6% more than the previous \
year.\
\>", "Text"],

Cell["year1 = year0 + year0 * .06", "Input"],

Cell["\<\
(6.3)  After another year passes we have 6% more than the previous \
year.\
\>", "Text"],

Cell["year2 = year1 + year1 * .06", "Input"],

Cell["\<\
(6.4)  After a third year passes we have 6% more than the previous \
year.\
\>", "Text"],

Cell["year3 = year2 + year2 * .06", "Input"],

Cell["\<\
(6.5)  Let's repeat (6.1) through (6.4) using symbols instead of \
numbers.  In the beginning we have a balance of $p.\
\>", "Text"],

Cell["year0 = p", "Input"],

Cell["\<\
(6.6)  After a year passes we have a factor of r more than the \
previous year.\
\>", "Text"],

Cell["year1 = year0 + year0 * r", "Input"],

Cell["\<\
(6.7)  After another year passes we have a factor of r more than \
the previous year.\
\>", "Text"],

Cell["year2 = year1 + year1 * r", "Input"],

Cell["\<\
(6.8)  After a third year passes we have a factor of r more than \
the previous year.\
\>", "Text"],

Cell["year3 = year2 + year2 * r", "Input"],

Cell["\<\
(6.9)  Let's do some algebraic manipulations on the exprssion from \
(6.8) to try and discover a pattern.  We can \"expand\" it, which distributes \
products over sums.\
\>", "Text"],

Cell["Expand[year3]", "Input"],

Cell["(6.10)  We can also \"factor\" it.  This looks promising.", "Text"],

Cell["Factor[year3]", "Input"],

Cell["\<\
(6.11)  Let's follow this up by factoring \"year2\".  This appears \
to confirm the pattern.\
\>", "Text"],

Cell["Factor[year2]", "Input"],

Cell["\<\
(6.12)  Let's factor the balance that would exist after four years.\
\
\>", "Text"],

Cell["Factor[year3 + year3 * r]", "Input"],

Cell["\<\
(6.14)  Based on the pattern that we uncovered in (6.10) through \
(6.12), let's create a programmer-defined function \"simple\".  It takes an \
initial balance \"p\", an interest rate \"r\", and a number of years \"n\", \
and returns the balance after \"n\" years.\
\>", "Text"],

Cell["simple[p_, r_, n_] := p * (r+1)^n", "Input"],

Cell["\<\
(6.15)  We can use \"simple\" to calculate the balance that will \
result by investing $1000 at 6% interest for 500 years ...\
\>", "Text"],

Cell["simple[1000, .06, 500]", "Input"],

Cell["\<\
(6.16)  ... and the balance that will result by investing $B at 10% \
interest for 8 years.\
\>", "Text"],

Cell["simple[B, .10, 8]", "Input"],

Cell["\<\
 We record the population of the United States on January 1, \
1994.\
\>", "Text"],

Cell["jan94 = 259167000.", "Input"],

Cell["And on January 1, 1995.", "Text"],

Cell["jan95 = 261638000.", "Input"],

Cell["\<\
(6.17)  If the population of the United States were growing \
according to a simple interest model, \"simpleGrowth\" would be the annual \
interest rate at which it grew in 1994.\
\>", "Text"],

Cell["simpleGrowth = (jan95 - jan94) / jan94", "Input"],

Cell["\<\
(6.18)  By applying the simple interest model to the population \
growth of the United States, we can project the population on January 1, \
2000.\
\>", "Text"],

Cell["simple[jan94, simpleGrowth, 6]", "Input"],

Cell["\<\
(6.19)  We can use the simple interest model to calculate compound \
interest.  Here we calculate the result of investing $1000 at 6% annual \
interest, compounded daily, for a period of one year.\
\>", "Text"],

Cell["simple[1000., .06/365, 365]", "Input"],

Cell["\<\
(6.20)  Here we repeat (6.19) symbolically.  We calculate the \
result of investing $p at r% annual interest, compounded daily, for a period \
of one year.\
\>", "Text"],

Cell["simple[p, r/365, 365]", "Input"],

Cell["\<\
(6.21)  We continue to generalize.  Here, we calculate the result \
of investing $p at r% annual interest, compounded daily, for a period of \
\"n\" years.\
\>", "Text"],

Cell["simple[p, r/365, 365*n]", "Input"],

Cell["\<\
(6.22)  Finally, we calculate the result of investing $p at r% \
annual interest, compounded \"m\" times per year, for a period of \"n\" \
years.  This gives us a general expression for compound interest. \
\>", 
  "Text"],

Cell["simple[p, r/m, m*n]", "Input"],

Cell["\<\
(6.23)  We convert the expression from (6.22) into a \"compound\" \
function.  It takes as parameters an initial balance \"p\", an interest rate \
\"r\", a period of years \"n\", and the number of compounding intervals per \
year \"m\".  It returns the result of investing $p at r% annual interest, \
compounded \"m\" times per year, for \"n\" years.\
\>", "Text"],

Cell["compound[p_,r_,n_,m_] := p * (1 + r/m)^(m*n)", "Input"],

Cell["\<\
(6.24)  We use \"compound\" to calculate the result of investing \
$1000 at 6% annual interest, compounded daily, for 500 years.\
\>", "Text"],

Cell["compound[1000, .06, 500, 365]", "Input"],

Cell["\<\
(6.26)  We use \"Solve\" to find find the simple interest rate \
\"r\" that corresponds to a 6% investment compounded daily.\
\>", "Text"],

Cell["Solve[simple[p, r, 1] == compound[p, .06, 1, 365], r]", "Input"],

Cell["\<\
(6.27)  We try to use \"Solve\" to find an interest rate \"r\" that \
we can use to model the growth of the population of the United States in \
1994, under the assumption that the growth occurs daily.  Unfortunately, \
\"Solve\" is unable to solve the 365th-degree polynomial equation.\
\>", 
  "Text"],

Cell["Solve[jan95 == compound[jan94, r, 1, 365], r]", "Input"],

Cell["\<\
(6.30)  We can rearrange the equation from (6.27) into a form with \
one root root that \"Solve\" can find.\
\>", "Text"],

Cell["Solve[1 + r/365 == (jan95/jan94)^(1/365), r]", "Input"],

Cell["\<\
(6.32)  We find the limit of a compound interest investment as the \
number of compounding intervals tends to infinity.  This is the continuous \
interest formula.\
\>", "Text"],

Cell["Limit[compound[p, r, n, m], m->Infinity]", "Input"],

Cell["\<\
(6.33)  We use the expression from (6.30) to create a function \
called \"continuous\".  It takes as parameters an initial balance \"p\", an \
interest rate \"r\", and a number of years \"n\", and returns the balance \
that will result from investing $p at r% continuous interest for \"n\" years.\
\
\>", "Text"],

Cell["continuous[p_,r_,n_] := p*Exp[n*r]", "Input"],

Cell["\<\
(6.34)  We use \"solve\" to find the continuous interest rate \"r\" \
that will allow us to model the growth of the population of the United States \
during 1994 as a problem in continuous interest.\
\>", "Text"],

Cell["Solve[jan95 == continuous[jan94,r,1], r]", "Input"],

Cell["\<\
(6.35)  We save the value for \"r\" found in (6.34) in the variable \
\"continuousGrowth\".\
\>", "Text"],

Cell["continuousGrowth = 0.00948923", "Input"],

Cell["\<\
(6.36)  We use the result of (6.34) to create a function \"dailyPop\
\" that takes \"days\" as its parameter.  It returns the population of the \
United States \"days\" days after January 1, 1994, assuming that the \
population grows according to the continuous interest model.  Notice that \
this function is defined in terms of another programmer-defined function, \
\"continuous\".\
\>", "Text"],

Cell["\<\
dailyPop[days_] := continuous[jan94, continuousGrowth, days/365.]\
\
\>", "Input"],

Cell["\<\
(6.37)  We use \"dailyPop\" to project the population of the United \
States at midnight on February 1, 1994.\
\>", "Text"],

Cell["dailyPop[31]", "Input"],

Cell["\<\
(6.38)  We use \"dailyPop\" to project the population of the United \
States at 6:00 am on February 1, 1994.\
\>", "Text"],

Cell["dailyPop[31.25]", "Input"],

Cell["\<\
(6.39)  We use \"InputForm\" to look at all of the digits of the \
solution we originally round in (6.34).\
\>", "Text"],

Cell["InputForm[Solve[jan95 == continuous[jan94,r,1], r]]", "Input"],

Cell["\<\
(6.40)  We use \"dailyPop\" to project the population of the United \
States at midnight on January 3, 1994.\
\>", "Text"],

Cell["dailyPop[2]", "Input"],

Cell["\<\
(6.41)  This is how we would have to do the calculation from (6.36) \
if we hadn't defined the \"dailyPop\" function.\
\>", "Text"],

Cell["259167000 * Exp[2/365 * .00948923]", "Input"],

Cell["\<\
(6.42)  Once a variable has been given a value via assignment, it \
cannot be used as a symbolic constant.\
\>", "Text"],

Cell["Solve[simpleGrowth^2 == 5, simpleGrowth]", "Input"],

Cell["(6.43)  We can \"unassign\" a variable by using \"Clear\".", "Text"],

Cell["Clear[simpleGrowth]", "Input"],

Cell["\<\
(6.44)  Once a variable has been \"unassigned\", it can be used as \
a symbolic constant once again.\
\>", "Text"],

Cell["Solve[simpleGrowth^2 == 5, simpleGrowth]", "Input"],

Cell["(6.46)  An example of the use of the \"Sum\" function.", "Text"],

Cell["Sum[n^2, {n,1,100}]", "Input"],

Cell["\<\
(6.47)  An example of using the \"Sum\" function to compute a sum \
over an infinite number of terms.\
\>", "Text"],

Cell["\<\
Sum[1/2^n, {n,1,Infinity}]
\
\>", "Input"]
}, Open  ]]
},
FrontEndVersion->"X 3.0",
ScreenRectangle->{{0, 1280}, {0, 1024}},
WindowSize->{520, 600},
WindowMargins->{{Automatic, 12}, {Automatic, 162}},
Magnification->1
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 258, 8, 62, "Subsection"],
Cell[1992, 61, 160, 4, 50, "Text"],
Cell[2155, 67, 30, 0, 27, "Input"],
Cell[2188, 69, 92, 3, 32, "Text"],
Cell[2283, 74, 44, 0, 27, "Input"],
Cell[2330, 76, 98, 3, 32, "Text"],
Cell[2431, 81, 44, 0, 27, "Input"],
Cell[2478, 83, 98, 3, 32, "Text"],
Cell[2579, 88, 44, 0, 27, "Input"],
Cell[2626, 90, 142, 3, 50, "Text"],
Cell[2771, 95, 26, 0, 27, "Input"],
Cell[2800, 97, 103, 3, 32, "Text"],
Cell[2906, 102, 42, 0, 27, "Input"],
Cell[2951, 104, 109, 3, 32, "Text"],
Cell[3063, 109, 42, 0, 27, "Input"],
Cell[3108, 111, 109, 3, 32, "Text"],
Cell[3220, 116, 42, 0, 27, "Input"],
Cell[3265, 118, 192, 4, 50, "Text"],
Cell[3460, 124, 30, 0, 27, "Input"],
Cell[3493, 126, 73, 0, 32, "Text"],
Cell[3569, 128, 30, 0, 27, "Input"],
Cell[3602, 130, 116, 3, 32, "Text"],
Cell[3721, 135, 30, 0, 27, "Input"],
Cell[3754, 137, 93, 3, 32, "Text"],
Cell[3850, 142, 42, 0, 27, "Input"],
Cell[3895, 144, 289, 5, 68, "Text"],
Cell[4187, 151, 50, 0, 27, "Input"],
Cell[4240, 153, 149, 3, 50, "Text"],
Cell[4392, 158, 39, 0, 27, "Input"],
Cell[4434, 160, 115, 3, 32, "Text"],
Cell[4552, 165, 34, 0, 27, "Input"],
Cell[4589, 167, 92, 3, 32, "Text"],
Cell[4684, 172, 35, 0, 27, "Input"],
Cell[4722, 174, 39, 0, 32, "Text"],
Cell[4764, 176, 35, 0, 27, "Input"],
Cell[4802, 178, 202, 4, 50, "Text"],
Cell[5007, 184, 55, 0, 27, "Input"],
Cell[5065, 186, 170, 4, 50, "Text"],
Cell[5238, 192, 47, 0, 27, "Input"],
Cell[5288, 194, 220, 4, 68, "Text"],
Cell[5511, 200, 44, 0, 27, "Input"],
Cell[5558, 202, 179, 4, 50, "Text"],
Cell[5740, 208, 38, 0, 27, "Input"],
Cell[5781, 210, 179, 4, 50, "Text"],
Cell[5963, 216, 40, 0, 27, "Input"],
Cell[6006, 218, 232, 5, 68, "Text"],
Cell[6241, 225, 36, 0, 27, "Input"],
Cell[6280, 227, 374, 6, 86, "Text"],
Cell[6657, 235, 61, 0, 27, "Input"],
Cell[6721, 237, 152, 3, 50, "Text"],
Cell[6876, 242, 46, 0, 27, "Input"],
Cell[6925, 244, 148, 3, 50, "Text"],
Cell[7076, 249, 70, 0, 27, "Input"],
Cell[7149, 251, 313, 6, 68, "Text"],
Cell[7465, 259, 62, 0, 27, "Input"],
Cell[7530, 261, 131, 3, 50, "Text"],
Cell[7664, 266, 61, 0, 27, "Input"],
Cell[7728, 268, 187, 4, 50, "Text"],
Cell[7918, 274, 57, 0, 27, "Input"],
Cell[7978, 276, 322, 6, 68, "Text"],
Cell[8303, 284, 51, 0, 27, "Input"],
Cell[8357, 286, 222, 4, 50, "Text"],
Cell[8582, 292, 57, 0, 27, "Input"],
Cell[8642, 294, 115, 3, 32, "Text"],
Cell[8760, 299, 46, 0, 27, "Input"],
Cell[8809, 301, 408, 7, 86, "Text"],
Cell[9220, 310, 92, 3, 42, "Input"],
Cell[9315, 315, 133, 3, 50, "Text"],
Cell[9451, 320, 29, 0, 27, "Input"],
Cell[9483, 322, 132, 3, 50, "Text"],
Cell[9618, 327, 32, 0, 27, "Input"],
Cell[9653, 329, 130, 3, 50, "Text"],
Cell[9786, 334, 68, 0, 27, "Input"],
Cell[9857, 336, 132, 3, 50, "Text"],
Cell[9992, 341, 28, 0, 27, "Input"],
Cell[10023, 343, 141, 3, 50, "Text"],
Cell[10167, 348, 51, 0, 27, "Input"],
Cell[10221, 350, 130, 3, 50, "Text"],
Cell[10354, 355, 57, 0, 27, "Input"],
Cell[10414, 357, 74, 0, 32, "Text"],
Cell[10491, 359, 36, 0, 27, "Input"],
Cell[10530, 361, 124, 3, 50, "Text"],
Cell[10657, 366, 57, 0, 27, "Input"],
Cell[10717, 368, 70, 0, 32, "Text"],
Cell[10790, 370, 36, 0, 27, "Input"],
Cell[10829, 372, 125, 3, 50, "Text"],
Cell[10957, 377, 52, 3, 42, "Input"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

