(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      9375,        349]*)
(*NotebookOutlinePosition[     10012,        372]*)
(*  CellTagsIndexPosition[      9968,        368]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  "This notebook contains the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " commands from Chapter 8 of ",
  StyleBox["Introduction to Scientific Programming",
    FontSlant->"Italic"],
  " by Joseph L. Zachary."
}], "Subsection"],

Cell["(8.1)  We record the mass, ", "Text"],

Cell["mass = 4.5*^6", "Input"],

Cell["(8.2)  maximum power output,", "Text"],

Cell["maxPower = 5.0*^6", "Input"],

Cell["(8.3) and drag coefficient for the destroyer.", "Text"],

Cell["drag = 5.5*^3", "Input"],

Cell["\<\
(8.4)  We define a symbolic expression that gives the position of \
the destroyer in terms of \"t\".  We will be ignoring the effects of drag in \
the first part of this notebook.\
\>", "Text"],

Cell["pos = .032 * t^2", "Input"],

Cell["\<\
(8.5)  We plot the position of the destroyer when it is near the \
origin.\
\>", "Text"],

Cell["Plot[pos, {t, -100, 100}, AxesLabel->{\"sec\", \"m\"}]", "Input"],

Cell["\<\
(8.6)  We plot the position of the destroyer for positive \
times.\
\>", "Text"],

Cell["Plot[pos, {t, 0, 200}, AxesLabel->{\"sec\", \"m\"}]", "Input"],

Cell["\<\
(8.8)  The velocity of the destroyer is the first derivative of \
position.\
\>", "Text"],

Cell["vel = D[pos, t]", "Input"],

Cell["\<\
(8.9)  The acceleration of the destroyer is the first derivative of \
velocity.\
\>", "Text"],

Cell["acc = D[vel, t]", "Input"],

Cell["\<\
(8.10)  The force required to move the destroyer along its \
trajectory is the product of mass and acceleration.\
\>", "Text"],

Cell["force = mass * acc", "Input"],

Cell["\<\
(8.11)  The power required to move the destroyer along its \
trajectory is the product of force and velocity.\
\>", "Text"],

Cell["pow = force * vel", "Input"],

Cell["\<\
(8.12)  We plot the power required to move the destroyer when it is \
close to the origin.\
\>", "Text"],

Cell["\<\
Plot[pow/1*^6, {t, -100, 100}, 
     AxesLabel->{\"sec\", \"MW\"}]\
\>", "Input"],

Cell["\<\
(8.13)  We plot the absolute value of the power required to move \
the destroyer when it is close to the origin.\
\>", "Text"],

Cell["\<\
Plot[Abs[pow]/1*^6, {t, -100, 100}, 
     AxesLabel->{\"sec\", \"MW\"}]\
\>", "Input"],

Cell["\<\
(8.14)  We use \"solve\" to find the two times at which the maximum \
power capacity of the destroyer is reached.\
\>", "Text"],

Cell["threshold = Solve[Abs[pow] == maxPower, t]", "Input"],

Cell["\<\
(8.15)  As a result of the assignment in (8.14), \"threshold\" is a \
list of two replacements.\
\>", "Text"],

Cell["threshold", "Input"],

Cell["\<\
(8.16)  We can obtain the first replacements by subscripting \
\"threshold\" with 1 ...\
\>", "Text"],

Cell["threshold[[1]]", "Input"],

Cell["\<\
(8.17)  ... and the second replacement by subscripting \
\"threshold\" with 2.\
\>", "Text"],

Cell["threshold[[2]]", "Input"],

Cell["\<\
(8.18)  We can obtain the speed of the destroyer when it reaches \
power threshold either \"by hand\" ...\
\>", "Text"],

Cell[".064 * 271.267", "Input"],

Cell["\<\
(8.19)  ... or by replacing all occurrences of \"t\" in the \"vel\" \
expression with the threshold time.\
\>", "Text"],

Cell["ReplaceAll[vel, threshold[[2]]]", "Input"],

Cell["\<\
(8.20)  We create a function \"makePower\" to calculate the power \
required, in the absence of drag, at any point of time along an arbitrary \
trajectory.  Here, \"pos\" is the trajectory expression (which must be a \
symbolic expression in \"t\") and \"mass\" is the mass of the destroyer.  In \
the body of the function, we use the \"D\" function to determine velocity and \
acceleration expressions.\
\>", "Text"],

Cell["makePower[pos_, mass_] := mass * D[D[pos,t],t] * D[pos,t]", "Input"],

Cell["\<\
(8.21)  We use \"makePower\" to calculate the power required to \
follow trajectory \"pos\".  As expected, we get the same result as in \
(8.9).\
\>", "Text"],

Cell["pow = makePower[pos, mass]", "Input"],

Cell["(8.22)  We calculate power expressions ...", "Text"],

Cell["pow1 = makePower[.016 * t^2, mass]", "Input"],

Cell["(8.23)  ... corresponding to two new trajectories.", "Text"],

Cell["pow2 = makePower[.002 * t^2, mass]", "Input"],

Cell["\<\
(8.24)  We find the times at which power threshold is reached for \
the first of the new trajectories.\
\>", "Text"],

Cell["threshold1 = Solve[Abs[pow1] == maxPower, t]", "Input"],

Cell["\<\
(8.25)  We find the velocity corresponding to one of the power \
thresholds for the first of the new trajectories.\
\>", "Text"],

Cell["ReplaceAll[D[.016*t^2, t], threshold1[[2]]]", "Input"],

Cell["\<\
(8.26)  We find the times at which power threshold is reached for \
the second of the new trajectories.\
\>", "Text"],

Cell["Solve[Abs[pow2] == maxPower, t]", "Input"],

Cell["\<\
(8.27)  We find the power required to follow a constant-velocity \
trajectory (in the absence of drag).\
\>", "Text"],

Cell["makePower[v*t, mass]", "Input"],

Cell["\<\
(8.28)  This function computes the power expression for a destroyer \
of the given \"mass\" and \"drag\" coefficient that is following the \
trajectory \"pos\" (where \"pos\" must be a symbolic expression in \"t\").  \
For the remainder of this notebook, we will consider the effects of drag on \
power requirements.\
\>", "Text"],

Cell["\<\
makePowerDrag[pos_, mass_, drag_] :=
    (mass * D[D[pos,t],t] + drag * D[pos,t]) *
       D[pos,t]\
\>", "Input"],

Cell["\<\
(8.29)  We calculate a power expression for a destroyer following \
our original trajectory of .032*t^2.\
\>", "Text"],

Cell["pow = makePowerDrag[pos, mass, drag]", "Input"],

Cell["(8.30)  We plot the power consumption calculated in (8.29).", "Text"],

Cell["\<\
Plot[pow/1*^6, {t, -100, 100},
     AxesLabel->{\"sec\", \"MW\"}]\
\>", "Input"],

Cell["\<\
(8.31)  We find the power in watts required at time t=100 ...\
\>", 
  "Text"],

Cell["Abs[ReplaceAll[pow, {t->100}]]", "Input"],

Cell["\<\
(8.32)  .. and t=-100 seconds when following the trajectory \
.032*t^2.\
\>", "Text"],

Cell["Abs[ReplaceAll[pow, {t->-100}]]", "Input"],

Cell["\<\
(8.33)  We plot the power consumption calculated in (8.30) over a \
different time range than we used in (8.26).\
\>", "Text"],

Cell["\<\
Plot[pow/1*^6, {t, -1000, 200},
     AxesLabel->{\"sec\", \"MW\"}]\
\>", "Input"],

Cell["\<\
(8.34)  We determine the times at which the power threshold is \
reached when following the trajectory from (8.30).\
\>", "Text"],

Cell["Solve[pow == maxPower, t]", "Input"],

Cell["\<\
(8.35)  We determine the power required to follow a \
constant-velocity trajectory (in the presence of drag).\
\>", "Text"],

Cell["constantPower = makePowerDrag[v*t, mass, drag]", "Input"],

Cell["\<\
(8.36)  We find the maximum sustainable velocities (in m/sec) for \
the destroyer in the presence of drag.\
\>", "Text"],

Cell["Solve[constantPower == maxPower, v]", "Input"],

Cell["\<\
(8.38)  We define a piecewise trajectory in which the destroyer \
begins at a rest, moves 10,000 meters, and ends at rest.\
\>", "Text"],

Cell["\<\
move = Which[t < -500, -5000,
             t < 500, 5000*Sin[Pi*t/1000],
             True, 5000]\
\>", "Input"],

Cell["(8.39)  We plot the piecewise trajectory from (8.38).", "Text"],

Cell["\<\
Plot[move, {t, -600, 600}, 
     AxesLabel->{\"sec\", \"m\"}]\
\>", "Input"],

Cell["\<\
(8.40)  We calculate the power required to follow the pieceewise \
trajectory from (8.38).\
\>", "Text"],

Cell["movePower = makePowerDrag[move, mass, drag]", "Input"],

Cell["\<\
(8.41)  We plot the power required to follow the piecewise \
trajectory from (8.38).\
\>", "Text"],

Cell["\<\
Plot[movePower/1*^6, {t, -600, 600},
     AxesLabel->{\"sec\", \"MW\"}]\
\>", "Input"]
}, Open  ]]
},
FrontEndVersion->"X 3.0",
ScreenRectangle->{{0, 1280}, {0, 1024}},
WindowSize->{520, 600},
WindowMargins->{{Automatic, 30}, {Automatic, 132}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 258, 8, 62, "Subsection"],
Cell[1992, 61, 43, 0, 32, "Text"],
Cell[2038, 63, 30, 0, 27, "Input"],
Cell[2071, 65, 44, 0, 32, "Text"],
Cell[2118, 67, 34, 0, 27, "Input"],
Cell[2155, 69, 61, 0, 32, "Text"],
Cell[2219, 71, 30, 0, 27, "Input"],
Cell[2252, 73, 203, 4, 50, "Text"],
Cell[2458, 79, 33, 0, 27, "Input"],
Cell[2494, 81, 98, 3, 32, "Text"],
Cell[2595, 86, 71, 0, 27, "Input"],
Cell[2669, 88, 90, 3, 32, "Text"],
Cell[2762, 93, 68, 0, 27, "Input"],
Cell[2833, 95, 99, 3, 32, "Text"],
Cell[2935, 100, 32, 0, 27, "Input"],
Cell[2970, 102, 103, 3, 32, "Text"],
Cell[3076, 107, 32, 0, 27, "Input"],
Cell[3111, 109, 136, 3, 50, "Text"],
Cell[3250, 114, 35, 0, 27, "Input"],
Cell[3288, 116, 133, 3, 50, "Text"],
Cell[3424, 121, 34, 0, 27, "Input"],
Cell[3461, 123, 114, 3, 32, "Text"],
Cell[3578, 128, 91, 3, 42, "Input"],
Cell[3672, 133, 136, 3, 50, "Text"],
Cell[3811, 138, 96, 3, 42, "Input"],
Cell[3910, 143, 137, 3, 50, "Text"],
Cell[4050, 148, 59, 0, 27, "Input"],
Cell[4112, 150, 119, 3, 32, "Text"],
Cell[4234, 155, 26, 0, 27, "Input"],
Cell[4263, 157, 111, 3, 32, "Text"],
Cell[4377, 162, 31, 0, 27, "Input"],
Cell[4411, 164, 102, 3, 32, "Text"],
Cell[4516, 169, 31, 0, 27, "Input"],
Cell[4550, 171, 129, 3, 50, "Text"],
Cell[4682, 176, 31, 0, 27, "Input"],
Cell[4716, 178, 129, 3, 32, "Text"],
Cell[4848, 183, 48, 0, 27, "Input"],
Cell[4899, 185, 427, 7, 104, "Text"],
Cell[5329, 194, 74, 0, 27, "Input"],
Cell[5406, 196, 168, 4, 50, "Text"],
Cell[5577, 202, 43, 0, 27, "Input"],
Cell[5623, 204, 58, 0, 32, "Text"],
Cell[5684, 206, 51, 0, 27, "Input"],
Cell[5738, 208, 66, 0, 32, "Text"],
Cell[5807, 210, 51, 0, 27, "Input"],
Cell[5861, 212, 126, 3, 50, "Text"],
Cell[5990, 217, 61, 0, 27, "Input"],
Cell[6054, 219, 138, 3, 50, "Text"],
Cell[6195, 224, 60, 0, 27, "Input"],
Cell[6258, 226, 127, 3, 50, "Text"],
Cell[6388, 231, 48, 0, 27, "Input"],
Cell[6439, 233, 127, 3, 50, "Text"],
Cell[6569, 238, 37, 0, 27, "Input"],
Cell[6609, 240, 340, 6, 86, "Text"],
Cell[6952, 248, 124, 4, 57, "Input"],
Cell[7079, 254, 128, 3, 50, "Text"],
Cell[7210, 259, 53, 0, 27, "Input"],
Cell[7266, 261, 75, 0, 32, "Text"],
Cell[7344, 263, 90, 3, 42, "Input"],
Cell[7437, 268, 88, 3, 32, "Text"],
Cell[7528, 273, 47, 0, 27, "Input"],
Cell[7578, 275, 95, 3, 32, "Text"],
Cell[7676, 280, 48, 0, 27, "Input"],
Cell[7727, 282, 136, 3, 50, "Text"],
Cell[7866, 287, 91, 3, 42, "Input"],
Cell[7960, 292, 139, 3, 50, "Text"],
Cell[8102, 297, 42, 0, 27, "Input"],
Cell[8147, 299, 133, 3, 50, "Text"],
Cell[8283, 304, 63, 0, 27, "Input"],
Cell[8349, 306, 130, 3, 50, "Text"],
Cell[8482, 311, 52, 0, 27, "Input"],
Cell[8537, 313, 146, 3, 50, "Text"],
Cell[8686, 318, 122, 4, 57, "Input"],
Cell[8811, 324, 69, 0, 32, "Text"],
Cell[8883, 326, 86, 3, 42, "Input"],
Cell[8972, 331, 114, 3, 32, "Text"],
Cell[9089, 336, 60, 0, 27, "Input"],
Cell[9152, 338, 108, 3, 32, "Text"],
Cell[9263, 343, 96, 3, 42, "Input"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

