(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     14013,        524]*)
(*NotebookOutlinePosition[     14667,        547]*)
(*  CellTagsIndexPosition[     14623,        543]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  "This notebook contains the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " commands from Chapter 9 of ",
  StyleBox["Introduction to Scientific Programming",
    FontSlant->"Italic"],
  " by Joseph L. Zachary."
}], "Subsection"],

Cell["(9.1)  The area of the \"slice\" of circle from Figure 9.1.", "Text"],

Cell["X = theta/(2*Pi) * Pi*R^2", "Input"],

Cell["(9.2)  The length of the side \"R\" from Figures 9.2 and 9.3.", "Text"],

Cell["R = 2 * r * Cos[theta/2]", "Input"],

Cell["(9.3)  The area of each of the triangles from Figure 9.2.", "Text"],

Cell["Y = 1/2 * R * r * Sin[theta/2]", "Input"],

Cell["(9.4)  The area of region \"Z\" from Figure 9.2.", "Text"],

Cell["Z = (2*theta)/(2*Pi) * Pi*r^2", "Input"],

Cell["\<\
(9.5)  The area of the region where the cow will be unable to \
graze.\
\>", "Text"],

Cell["A = Z - (X - 2*Y)", "Input"],

Cell["\<\
(9.6)  We simplify the expression from (9.5) by using the \
\"Simplify\" function.\
\>", "Text"],

Cell["Simplify[A]", "Input"],

Cell["(9.9)  A simple example of using the \"Solve\" function.", "Text"],

Cell["Solve[2*x == 4, x]", "Input"],

Cell["\<\
(9.10)  Using the \"Solve\" function to solve two simultaneous \
linear equations.\
\>", "Text"],

Cell["Solve[{3*x + 2*y == 7, x + y == 3}, {x,y}]", "Input"],

Cell["\<\
(9.11)  Using the \"Solve\" function to solve a quadratic equation.\
\
\>", "Text"],

Cell["Solve[2*x^2 - 3*x - 9 == 0, x]", "Input"],

Cell["\<\
(9.12)  Using the \"Solve\" function to solve a trigonometric \
equation.\
\>", "Text"],

Cell["Solve[Cos[alpha] == Sin[alpha], alpha]", "Input"],

Cell["\<\
(9.13)  Using the \"Solve\" function to solve a symbolic quadratic \
equation.  Notice that the result is the quadratic formula.\
\>", "Text"],

Cell["Solve[a*x^2 + b*x + c == 0, x]", "Input"],

Cell["\<\
(9.14)  Unfortunately, \"Solve\" can't solve just anything.  Here \
we try (and fail) to solve the equation that is at the root of Old \
MacDonald's problem.\
\>", "Text"],

Cell["\<\
Solve[Sin[theta] - theta*Cos[theta] == Pi/2,
      theta]\
\>", "Input"],

Cell["\<\
(9.15)  The \"FindRoot\" function uses numerical techniques to \
solve equation.  It often succeeds where \"Solve\" fails.\
\>", "Text"],

Cell["\<\
angle =
  FindRoot[Sin[theta] - theta*Cos[theta] == Pi/2,
           {theta, 1.0}]\
\>", "Input"],

Cell["\<\
(9.16)  We compare the values of the two sides of the equation from \
(9.15) when the solution (\"angle\") is substituted for \"theta\".  This is \
the left-hand side ...\
\>", "Text"],

Cell["\<\
ans1 =  ReplaceAll[Sin[theta] - theta*Cos[theta],
                   angle]
\
\>", "Input"],

Cell["(9.17)  ... and this is the right-hand side.", "Text"],

Cell["ans2 = N[Pi/2]", "Input"],

Cell["\<\
(9.18)  The two values look to be the same.  But if we look in more \
detail at the left- \
\>", "Text"],

Cell["InputForm[ans1]", "Input"],

Cell["\<\
(9.19)  and right-hand sides, we see that they are quite different \
in the low-order digits.\
\>", "Text"],

Cell["InputForm[ans2]", "Input"],

Cell["\<\
(9.20)  We can use the \"AccuracyGoal\" optional parameter to ask \
\"FindRoot\" to deliver a more accurate answer.\
\>", "Text"],

Cell["\<\
newangle =
  FindRoot[Sin[theta] - theta*Cos[theta] == Pi/2,
           {theta, 1.0},
           AccuracyGoal->16]\
\>", "Input"],

Cell["\<\
(9.21)  Now we can determine the value of the right-hand side ...\
\
\>", "Text"],

Cell["\<\
ans3 = ReplaceAll[Sin[theta] - theta*Cos[theta],
                  newangle]\
\>", "Input"],

Cell["(9.22)  ... and see that it is much improved.", "Text"],

Cell["InputForm[ans3]", "Input"],

Cell["\<\
(9.23)  Because it operates numerically, \"FindRoot\" cannot be \
used to find symbolic solutions.\
\>", "Text"],

Cell["FindRoot[a*x^2 + b*x + c == 0, {x, 1.0}]", "Input"],

Cell["\<\
(9.24)  We need to find the root of this function to solve Old \
MacDonald's problem.\
\>", "Text"],

Cell["cow[theta_] := Sin[theta] - theta*Cos[theta] - Pi/2", "Input"],

Cell["\<\
(9.25)  This demonstrates that the \"cow\" function is positive at \
2.5 ...\
\>", "Text"],

Cell["cow[2.5]", "Input"],

Cell["\<\
(9.26)  ... and negative at 1.5.  Thus, a root of \"cow\" must lie \
somewhere in between.\
\>", "Text"],

Cell["cow[1.5]", "Input"],

Cell["\<\
(9.27)  This plot verifies that a root of \"cow\" lies between 1.5 \
and 2.5.\
\>", "Text"],

Cell["Plot[cow[theta], {theta, 1.5, 2.5}]", "Input"],

Cell["\<\
(9.28)  Midway between 1.5 and 2.5, \"cow\" is positive.  This \
means that a root lies somewhere between 1.5 (where \"cow\" is negative) and \
2.0.\
\>", "Text"],

Cell["cow[2.0]", "Input"],

Cell["\<\
(9.29)  This plot verifies that a root of \"cow\" lies between 1.5 \
and 2.0.\
\>", "Text"],

Cell["Plot[cow[theta], {theta, 1.5, 2.0}]", "Input"],

Cell["\<\
(9.30)  Midway between 1.5 and 2.0, \"cow\" is negative.  This \
narrows the interval in which a root of \"cow\" must lie to 1.75--2.0.\
\>", 
  "Text"],

Cell["cow[1.75]", "Input"],

Cell["\<\
(9.31)  It would be nice if we had a bisection function that worked \
as illustrated below.  We would pass it the function whose root we wished to \
find, a value at which the function was positive, and a value at which the \
function was negative.  For the remainder of this notebook we will work \
towards developing such a function.\
\>", "Text"],

Cell["bisection[cow, 2.5, 1.5]", "Input"],

Cell["\<\
(9.32)  This is an example of an expression sequence.  The \
expressions are evaluated from left to right, and only the value of the last \
one is displayed.  Since all three of these expressions are pure expressions, \
there is no point to arranging them in a sequence.\
\>", "Text"],

Cell["(1+1; 2+2; 3+3)", "Input"],

Cell["\<\
(9.33)   The order in which imperative expressions are evaluated \
can make a difference.  Compare the final value of \"y\" in this sequence ...\
\
\>", "Text"],

Cell["(x=1; x=2; y=x^2; y)", "Input"],

Cell["\<\
(9.34)  ... and in this sequence.  The only difference is that we \
have permuted the order of the second and third assignments.\
\>", "Text"],

Cell["(x=1; y=x^2; x=2; y)", "Input"],

Cell["\<\
(Figure 9.5)  This is the beginning of our attempt to automate the \
bisection process.  We begin with a function \"f\" to be solved and values \
\"pos\" and \"neg\" such that f(pos)>0 and f(neg)<0.  We repeatedly average \
\"pos\" and \"neg\", test the value of \"f\" at the average, and update \
either \"pos\" or \"neg\" appropriately.  Notice that we (as the creators of \
the expression sequence) had to determine whether to update \"pos\" or \
\"neg\" at each step.  If we were to repeat this process enough times, we \
would narrow down on a root of \"f\".\
\>", "Text"],

Cell["\<\
(f = cow;
 pos = 2.5;
 neg = 1.5;
 
 avg = (pos + neg) / 2.0;
 f[avg];
 pos = avg;
 
 avg = (pos + neg) / 2.0;
 f[avg];
 neg = avg;
 
 avg)
\
\>", "Input"],

Cell["\<\
(Figure 9.6)  Here we have inserted conditional expressions into \
our expression sequence.  These conditionals decide whether to update \"pos\" \
or \"neg\" at each step.\
\>", "Text"],

Cell["\<\
(f = cow;
 pos = 2.5;
 neg = 1.5;
 
 avg = (pos + neg) / 2.0;
 If[f[avg] >= 0,
    pos = avg,
    neg = avg];
    
 avg = (pos + neg) / 2.0;
 If[f[avg] >= 0,
    pos = avg,
    neg = avg];
    
 avg)\
\>", "Input"],

Cell["\<\
(Figure 9.7)  The example above contained two consecutive identical \
expression sequences.  Here, we make that expression sequence the body of a \
\"While\" expression, which repeatedly executes its body until the difference \
between \"pos\" and \"neg\" is small.\
\>", "Text"],

Cell["\<\
(f = cow;
 pos = 2.5;
 neg = 1.5;
 
 While[Abs[pos-neg] >= 1*^-6,
       (avg = (pos + neg) / 2.0;  
        If[f[avg] >= 0,
           pos = avg,
           neg = avg])];
           
 avg)\
\>", "Input"],

Cell["\<\
(9.38)  After the while loop above has run, the value of \"avg\" is \
fairly close to being a root of \"cow\".\
\>", "Text"],

Cell["cow[avg]", "Input"],

Cell["\<\
(Figure 9.8)  We embed the expression from (Figure 9.7) inside a \
module.  The variables \"f\", \"pos\", \"neg\", and \"avg\" are now local to \
the module.\
\>", "Text"],

Cell["\<\
Module[{f, pos, neg, avg},
       (f = cow;
        pos = 2.5;
        neg = 1.5;
        
        While[Abs[pos-neg] >= 1*^-6,
              (avg = (pos + neg) / 2.0;  
               If[f[avg] >= 0,
                  pos = avg,
                  neg = avg])];
                  
        avg)]
\
\>", "Input"],

Cell["\<\
(Figure 9.9)    This function encapsulates the bisection process.  \
It takes three parameters:  the \"function\" to be solved, a \"positive\" \
guess such that function(positive)>0, and a \"negative\" guess such that \
function(negative)<0.  It returns an approximation to a root of \"function\".\
\
\>", "Text"],

Cell["\<\
bisection[function_, positive_, negative_] :=
  Module[{f, pos, neg, avg},
         (f = function;
          pos = positive;
          neg = negative;
          While[Abs[pos-neg] >= 1*^-6,
                (avg = (pos + neg) / 2.0;  
                 If[f[avg] >= 0,
                    pos = avg,
                    neg = avg])];
          avg)]\
\>", "Input"],

Cell["\<\
(9.40)  We use the \"bisection\" procedure to approximate a root of \
\"cow\".\
\>", "Text"],

Cell["bisection[cow, 2.5, 1.5]", "Input"],

Cell["\<\
(9.42)  We compare the roots to \"cow\" found by \"FindRoot\" ... \
\
\>", "Text"],

Cell["\<\
InputForm[FindRoot[cow[theta], {theta, 1.0},
          AccuracyGoal->16]]\
\>", "Input"],

Cell["\<\
(9.43)  ... and \"bisection\".  They differ markedly, which is \
evidence that the convergence criterion used by \"bisection\" could be \
improved.\
\>", "Text"],

Cell["InputForm[bisection[cow, 2.5, 1.5]]", "Input"],

Cell["(9.44)  This function has a single large root.", "Text"],

Cell["bigRoot[x_] := x - 2.*^20", "Input"],

Cell["\<\
(9.45)  If we try to use \"bisection\" to find the function's root, \
the while loop that it contains will never terminate because the positive and \
negative guesses will never get very close together.  If you evaluate this \
expression, you will need to interrupt the execution.\
\>", "Text"],

Cell["bisection[bigRoot, 3.*^20, 1.*^20]", "Input"],

Cell["(9.46)  This function has a single small root.", "Text"],

Cell["smallRoot[x_] := x - 1.*^-20", "Input"],

Cell["\<\
(9.47)  If we try to use \"bisection\" to find the function's root, \
we won't get very close to a root (on a relative basis).  The root is so \
small that the positive and negative guesses get within 10^(-6) very quickly.\
\
\>", "Text"],

Cell["bisection[smallRoot, 1.0, 0.0]", "Input"],

Cell["\<\
(9.48)  In this case, the two guesses are so close together to \
begin with that the while loop within \"bisection\" is never executed, which \
means that \"avg\" is never given a value, which means that a useless \
symbolic result is reported.\
\>", "Text"],

Cell["bisection[smallRoot, 2.*^-8, 0]", "Input"],

Cell["\<\
(9.49)  If we supply faulty positive and negative guesses, \
\"bisection\" will converge to one of the guesses, and not to a root.\
\>", 
  "Text"],

Cell["bisection[bigRoot, 1.*^20, 3.*^20]", "Input"],

Cell["\<\
(Figure 9.10)  This is an improved version of \"bisection\".  It \
makes sure that \"positive\" and \"negative\" have the correct properties, \
make sure that a number is returned as the result under all circumstances, \
and uses an improved convergence criterion.\
\>", "Text"],

Cell["\<\
bisection[function_, positive_, negative_] :=

  Module[{f, pos, neg, avg, delta},
  
         (f = function;
          pos = positive;
          neg = negative;
          
          If[f[pos]<0, Return[\"Positive guess is bad\"]];
          If[f[neg]>0, Return[\"Negative guess is bad\"]];
          
\t      delta = Abs[pos-neg] * 2;
\t      
          While[Abs[pos-neg] < delta,
                (avg = (pos + neg) / 2.0;
                 delta = Abs[pos-neg];
                 If[f[avg] >= 0,
                    pos = avg,
                    neg = avg])];
                    
          avg)]\
\>", "Input"],

Cell["\<\
(9.51)  We can now compare the improved \"bisection\" to \"FindRoot\
\".  \
\>", "Text"],

Cell["InputForm[bisection[cow, 2.5, 1.5]]", "Input"]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 1600}, {0, 1144}},
WindowSize->{504, 584},
WindowMargins->{{344, Automatic}, {Automatic, 102}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 258, 8, 68, "Subsection"],
Cell[1992, 61, 75, 0, 33, "Text"],
Cell[2070, 63, 42, 0, 30, "Input"],
Cell[2115, 65, 77, 0, 33, "Text"],
Cell[2195, 67, 41, 0, 30, "Input"],
Cell[2239, 69, 73, 0, 33, "Text"],
Cell[2315, 71, 47, 0, 30, "Input"],
Cell[2365, 73, 64, 0, 33, "Text"],
Cell[2432, 75, 46, 0, 30, "Input"],
Cell[2481, 77, 94, 3, 33, "Text"],
Cell[2578, 82, 34, 0, 30, "Input"],
Cell[2615, 84, 106, 3, 33, "Text"],
Cell[2724, 89, 28, 0, 30, "Input"],
Cell[2755, 91, 72, 0, 33, "Text"],
Cell[2830, 93, 35, 0, 30, "Input"],
Cell[2868, 95, 106, 3, 33, "Text"],
Cell[2977, 100, 59, 0, 30, "Input"],
Cell[3039, 102, 93, 3, 33, "Text"],
Cell[3135, 107, 47, 0, 30, "Input"],
Cell[3185, 109, 97, 3, 33, "Text"],
Cell[3285, 114, 55, 0, 30, "Input"],
Cell[3343, 116, 152, 3, 52, "Text"],
Cell[3498, 121, 47, 0, 30, "Input"],
Cell[3548, 123, 181, 4, 52, "Text"],
Cell[3732, 129, 82, 3, 48, "Input"],
Cell[3817, 134, 146, 3, 52, "Text"],
Cell[3966, 139, 107, 4, 66, "Input"],
Cell[4076, 145, 194, 4, 52, "Text"],
Cell[4273, 151, 101, 4, 66, "Input"],
Cell[4377, 157, 60, 0, 33, "Text"],
Cell[4440, 159, 31, 0, 30, "Input"],
Cell[4474, 161, 114, 3, 33, "Text"],
Cell[4591, 166, 32, 0, 30, "Input"],
Cell[4626, 168, 117, 3, 33, "Text"],
Cell[4746, 173, 32, 0, 30, "Input"],
Cell[4781, 175, 139, 3, 52, "Text"],
Cell[4923, 180, 139, 5, 84, "Input"],
Cell[5065, 187, 91, 3, 33, "Text"],
Cell[5159, 192, 101, 3, 48, "Input"],
Cell[5263, 197, 61, 0, 33, "Text"],
Cell[5327, 199, 32, 0, 30, "Input"],
Cell[5362, 201, 122, 3, 33, "Text"],
Cell[5487, 206, 57, 0, 30, "Input"],
Cell[5547, 208, 109, 3, 33, "Text"],
Cell[5659, 213, 68, 0, 30, "Input"],
Cell[5730, 215, 100, 3, 33, "Text"],
Cell[5833, 220, 25, 0, 30, "Input"],
Cell[5861, 222, 114, 3, 33, "Text"],
Cell[5978, 227, 25, 0, 30, "Input"],
Cell[6006, 229, 101, 3, 33, "Text"],
Cell[6110, 234, 52, 0, 30, "Input"],
Cell[6165, 236, 172, 4, 52, "Text"],
Cell[6340, 242, 25, 0, 30, "Input"],
Cell[6368, 244, 101, 3, 33, "Text"],
Cell[6472, 249, 52, 0, 30, "Input"],
Cell[6527, 251, 162, 4, 52, "Text"],
Cell[6692, 257, 26, 0, 30, "Input"],
Cell[6721, 259, 359, 6, 90, "Text"],
Cell[7083, 267, 41, 0, 30, "Input"],
Cell[7127, 269, 294, 5, 71, "Text"],
Cell[7424, 276, 32, 0, 30, "Input"],
Cell[7459, 278, 170, 4, 52, "Text"],
Cell[7632, 284, 37, 0, 30, "Input"],
Cell[7672, 286, 152, 3, 52, "Text"],
Cell[7827, 291, 37, 0, 30, "Input"],
Cell[7867, 293, 587, 9, 128, "Text"],
Cell[8457, 304, 165, 15, 264, "Input"],
Cell[8625, 321, 195, 4, 52, "Text"],
Cell[8823, 327, 224, 16, 282, "Input"],
Cell[9050, 345, 289, 5, 71, "Text"],
Cell[9342, 352, 214, 12, 210, "Input"],
Cell[9559, 366, 134, 3, 52, "Text"],
Cell[9696, 371, 25, 0, 30, "Input"],
Cell[9724, 373, 181, 4, 52, "Text"],
Cell[9908, 379, 320, 14, 246, "Input"],
Cell[10231, 395, 323, 6, 71, "Text"],
Cell[10557, 403, 372, 12, 210, "Input"],
Cell[10932, 417, 102, 3, 33, "Text"],
Cell[11037, 422, 41, 0, 30, "Input"],
Cell[11081, 424, 92, 3, 33, "Text"],
Cell[11176, 429, 98, 3, 48, "Input"],
Cell[11277, 434, 171, 4, 52, "Text"],
Cell[11451, 440, 52, 0, 30, "Input"],
Cell[11506, 442, 62, 0, 33, "Text"],
Cell[11571, 444, 42, 0, 30, "Input"],
Cell[11616, 446, 304, 5, 71, "Text"],
Cell[11923, 453, 51, 0, 30, "Input"],
Cell[11977, 455, 62, 0, 33, "Text"],
Cell[12042, 457, 45, 0, 30, "Input"],
Cell[12090, 459, 248, 5, 71, "Text"],
Cell[12341, 466, 47, 0, 30, "Input"],
Cell[12391, 468, 268, 5, 71, "Text"],
Cell[12662, 475, 48, 0, 30, "Input"],
Cell[12713, 477, 157, 4, 52, "Text"],
Cell[12873, 483, 51, 0, 30, "Input"],
Cell[12927, 485, 288, 5, 71, "Text"],
Cell[13218, 492, 623, 22, 390, "Input"],
Cell[13844, 516, 98, 3, 33, "Text"],
Cell[13945, 521, 52, 0, 30, "Input"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

